package ink.wgink.common.startup;

import ink.wgink.common.dao.env.IEnvDao;
import ink.wgink.common.manager.env.EnvManager;
import ink.wgink.interfaces.init.IInitBaseMenu;
import ink.wgink.interfaces.init.IInitBaseTable;
import ink.wgink.interfaces.init.IInitBaseUser;
import ink.wgink.properties.ServerProperties;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * When you feel like quitting. Think about why you started
 * 当你想要放弃的时候，想想当初你为何开始
 *
 * @ClassName: CommonStartup
 * @Description: 启动
 * @Author: WangGeng
 * @Date: 2021/6/14 22:14
 * @Version: 1.0
 **/
@Component
public class CommonStartup implements ApplicationRunner {

    private ApplicationContext applicationContext;
    @Autowired
    private ServerProperties serverProperties;
    @Autowired(required = false)
    private IInitBaseMenu initBaseMenu;
    @Autowired(required = false)
    private IInitBaseUser initBaseUser;
    private IEnvDao envDao;

    public CommonStartup(ApplicationContext applicationContext, IEnvDao envDao) {
        this.applicationContext = applicationContext;
        this.envDao = envDao;
    }

    @Override
    public void run(ApplicationArguments args) throws Exception {
        if (serverProperties.getInit() == null || serverProperties.getInit().getTable()) {
            // 建表
            Map<String, IInitBaseTable> initBaseTableMap = applicationContext.getBeansOfType(IInitBaseTable.class);
            for (Map.Entry<String, IInitBaseTable> kv : initBaseTableMap.entrySet()) {
                kv.getValue().createTable();
            }
        }
        if (serverProperties.getInit() == null || serverProperties.getInit().getMenu()) {
            // 初始化菜单
            if (initBaseMenu != null) {
                initBaseMenu.init();
            }
        }
        if (serverProperties.getInit() == null || serverProperties.getInit().getUser()) {
            // 创建用户
            if (initBaseUser != null) {
                initBaseUser.init();
            }
        }
        // 初始化环境变量
        EnvManager envManager = EnvManager.getInstance();
        envManager.setEnvDao(envDao);
        envManager.refreshEnv();
    }
}
